@@ -113,7 +113,7 @@ class RTM::SessionPrivate {
     if (!online)
       return;
 
-    qDebug() << "Populating Smart List: " << list->name();
+    qDebug() << "Populating Smart List: " << list->name() << " with id " << list->id();
     // We do this next bit manually so it doesn't get auto-connected to taskUpdate()
     RTM::Request *smartListRequest = new RTM::Request("rtm.tasks.getList", q->apiKey(), q->sharedSecret());
     smartListRequest->addArgument("auth_token", q->token());
@@ -220,11 +220,8 @@ class RTM::SessionPrivate {
     reader.read();
     RTM::List* list = lists.value(id);
     if (list) {
-      list->tasks.clear();
-      foreach(RTM::Task* task, changedTasks) {
-        list->tasks.insert(task->id(), task);
-      }
-      changedLists.push_back(list);
+        list->setTasks(changedTasks);
+        changedLists.push_back(list);
     }
     applyChanges();
 
@@ -239,8 +236,10 @@ class RTM::SessionPrivate {
     timezone.truncate(timezone.indexOf("</timezone>"));
     QString dateformat = reply.remove(0, reply.indexOf("<dateformat>"+12));
     dateformat.truncate(dateformat.indexOf("</dateformat>"));
+    this->dateFormat = (dateformat.toInt() == 0 ? "dd/MM/yy" : "MM/dd/yy");
     QString timeformat = reply.remove(0, reply.indexOf("<timeformat>"+12));
     timeformat.truncate(timeformat.indexOf("</timeformat>"));
+    this->timeFormat = (timeformat.toInt() == 0 ? "hh:mm ap" : "hh:mm");
     QString defaultlist = reply.remove(0, reply.indexOf("<defaultlist>"+13));
     defaultlist.truncate(defaultlist.indexOf("</defaultlist>"));
 
@@ -279,6 +278,8 @@ class RTM::SessionPrivate {
 #ifndef QTONLY
   KTimeZone timezone;
 #endif
+  QString dateFormat; // user's dateformat choice: 0 - DD/MM/YY ,1 - MM/DD/YY
+  QString timeFormat; // user's timeformat choice: 0 - hh:mm ap ,1 - hh:mm
 
   RTM::Timeline timeline;
 
