@@ -44,27 +44,27 @@ AudioPlayerControlRunnerConfig::AudioPlayerControlRunnerConfig(QWidget* parent,
     connect(m_ui->searchCollection, SIGNAL(stateChanged(int)),this,SLOT(changed()));
     connect(m_ui->player_combo, SIGNAL(currentIndexChanged(int)), this, SLOT(changed()));
     connect(m_ui->player_combo, SIGNAL(editTextChanged(QString)), this, SLOT(changed()));
-    connect(m_ui->play_edit, SIGNAL(textChanged(const QString)), this, SLOT(changed()));
-    connect(m_ui->append_edit, SIGNAL(textChanged(const QString)),this,SLOT(changed()));
-    connect(m_ui->queue_edit, SIGNAL(textChanged(const QString)),this,SLOT(changed()));
-    connect(m_ui->pause_edit, SIGNAL(textChanged(const QString)), this, SLOT(changed()));
-    connect(m_ui->next_edit, SIGNAL(textChanged(const QString)), this, SLOT(changed()));
-    connect(m_ui->mute_edit, SIGNAL(textChanged(const QString)), this, SLOT(changed()));
-    connect(m_ui->up_edit, SIGNAL(textChanged(const QString)), this, SLOT(changed()));
+    connect(m_ui->play_edit, SIGNAL(textChanged(QString)), this, SLOT(changed()));
+    connect(m_ui->append_edit, SIGNAL(textChanged(QString)),this,SLOT(changed()));
+    connect(m_ui->queue_edit, SIGNAL(textChanged(QString)),this,SLOT(changed()));
+    connect(m_ui->pause_edit, SIGNAL(textChanged(QString)), this, SLOT(changed()));
+    connect(m_ui->next_edit, SIGNAL(textChanged(QString)), this, SLOT(changed()));
+    connect(m_ui->mute_edit, SIGNAL(textChanged(QString)), this, SLOT(changed()));
+    connect(m_ui->up_edit, SIGNAL(textChanged(QString)), this, SLOT(changed()));
     connect(m_ui->up_value, SIGNAL(valueChanged(int)), this, SLOT(changed()));
-    connect(m_ui->down_edit, SIGNAL(textChanged(const QString)), this, SLOT(changed()));
+    connect(m_ui->down_edit, SIGNAL(textChanged(QString)), this, SLOT(changed()));
     connect(m_ui->down_value, SIGNAL(valueChanged(int)), this, SLOT(changed()));
-    connect(m_ui->prev_edit, SIGNAL(textChanged(const QString)), this, SLOT(changed()));
-    connect(m_ui->stop_edit, SIGNAL(textChanged(const QString)), this, SLOT(changed()));
-    connect(m_ui->volume_edit, SIGNAL(textChanged(const QString)), this, SLOT(changed()));
-    connect(m_ui->quit_edit, SIGNAL(textChanged(const QString)), this, SLOT(changed()));
+    connect(m_ui->prev_edit, SIGNAL(textChanged(QString)), this, SLOT(changed()));
+    connect(m_ui->stop_edit, SIGNAL(textChanged(QString)), this, SLOT(changed()));
+    connect(m_ui->volume_edit, SIGNAL(textChanged(QString)), this, SLOT(changed()));
+    connect(m_ui->quit_edit, SIGNAL(textChanged(QString)), this, SLOT(changed()));
 
 
     /* Setup the combobox to select the player */
     m_ui->player_combo->setDuplicatesEnabled(false);
     connect(m_ui->player_combo, SIGNAL(currentIndexChanged(int)), this, SLOT(onPlayerChanged(int)));
     connect(m_ui->player_combo, SIGNAL(editTextChanged(QString)), this, SLOT(onPlayerChanged(QString)));
-    m_ui->player_combo->addItem(i18n("Amarok"), "amarok");
+    m_ui->player_combo->addItem(i18n("Amarok"), QLatin1String("amarok"));
     /* template for adding other players:
      * m_ui->player_combo->addItem(i18n("player's name"), "the end of it's MPRIS interface");
      */
@@ -77,7 +77,7 @@ void AudioPlayerControlRunnerConfig::load()
 {
     KCModule::load();
 
-    KSharedConfig::Ptr cfg = KSharedConfig::openConfig("krunnerrc");
+    KSharedConfig::Ptr cfg = KSharedConfig::openConfig(QLatin1String("krunnerrc"));
     KConfigGroup grp = cfg->group("Runners");
     grp = KConfigGroup(&grp, "Audio Player Control Runner");
     QString player = grp.readEntry(CONFIG_PLAYER, "amarok");
@@ -96,9 +96,9 @@ void AudioPlayerControlRunnerConfig::load()
     m_ui->pause_edit->setText(grp.readEntry(CONFIG_PAUSE, i18n("pause")));
     m_ui->next_edit->setText(grp.readEntry(CONFIG_NEXT, i18nc("next song", "next")));
     m_ui->mute_edit->setText(grp.readEntry(CONFIG_MUTE , i18n("mute")));
-    m_ui->up_edit->setText(grp.readEntry(CONFIG_INCREASE, i18nc("increase the sound volume", "up")));
+    m_ui->up_edit->setText(grp.readEntry(CONFIG_INCREASE, i18nc("increase the sound volume", "increase")));
     m_ui->up_value->setValue(grp.readEntry(CONFIG_INCREASE_BY , 15));
-    m_ui->down_edit->setText(grp.readEntry(CONFIG_DECREASE , i18nc("decrease the sound volume", "down")));
+    m_ui->down_edit->setText(grp.readEntry(CONFIG_DECREASE , i18nc("decrease the sound volume", "decrease")));
     m_ui->down_value->setValue(grp.readEntry(CONFIG_DECREASE_BY, 15));
     m_ui->prev_edit->setText(grp.readEntry(CONFIG_PREV , i18nc("previous song", "prev")));
     m_ui->stop_edit->setText(grp.readEntry(CONFIG_STOP , i18n("stop")));
@@ -112,7 +112,7 @@ void AudioPlayerControlRunnerConfig::save()
 {
     KCModule::save();
 
-    KSharedConfig::Ptr cfg = KSharedConfig::openConfig("krunnerrc");
+    KSharedConfig::Ptr cfg = KSharedConfig::openConfig(QLatin1String("krunnerrc"));
     KConfigGroup grp = cfg->group("Runners");
     grp = KConfigGroup(&grp, "Audio Player Control Runner");
     if (!m_ui->searchCollection->isEnabled()) {
@@ -152,7 +152,7 @@ void AudioPlayerControlRunnerConfig::defaults()
 {
     KCModule::defaults();
 
-    m_ui->player_combo->setCurrentIndex(m_ui->player_combo->findData("amarok"));
+    m_ui->player_combo->setCurrentIndex(m_ui->player_combo->findData(QLatin1String("amarok")));
     m_ui->searchCollection->setChecked(true);
     m_ui->commands->setChecked(true);
     m_ui->play_edit->setText(i18n("Play"));
@@ -167,7 +167,7 @@ void AudioPlayerControlRunnerConfig::defaults()
     m_ui->down_value->setValue(15);
     m_ui->prev_edit->setText(i18n("Prev"));
     m_ui->stop_edit->setText(i18n("Stop"));
-    m_ui->volume_edit->setText(i18n("Volume="));
+    m_ui->volume_edit->setText(i18n("Volume"));
     m_ui->quit_edit->setText(i18n("Quit"));
 
     emit changed(true);
@@ -175,8 +175,8 @@ void AudioPlayerControlRunnerConfig::defaults()
 
 void AudioPlayerControlRunnerConfig::onPlayerChanged(int index)
 {
-    QString data = m_ui->player_combo->itemData(index).toString();
-    if (data != "amarok") {
+    const QString data = m_ui->player_combo->itemData(index).toString();
+    if (data != QLatin1String("amarok")) {
         m_ui->searchCollection->setEnabled(false);
     } else {
         m_ui->searchCollection->setEnabled(true);
